pub enum RetryStrategy {
None,
Default,
All,
Custom {
status_codes: Vec<StatusCode>,
},
}Expand description
Configurable retry strategy for http based sinks.
For more information about error responses, see Client Error Responses.
Variants
None
Don’t retry any errors, including request timeouts.
Default
Default strategy. See RetryStrategy::retry_action for more details.
All
Retry on all HTTP status codes except for success codes (2xx)
Custom
Custom retry strategy
Fields

status_codes: Vec<StatusCode>Retry on these specific HTTP status codes
Implementations
Sourceimpl RetryStrategy
impl RetryStrategy
Sourcepub fn retry_action<Req>(&self, status: StatusCode) -> RetryAction<Req>
pub fn retry_action<Req>(&self, status: StatusCode) -> RetryAction<Req>
Determines if the given status code should be retried.
For the Default strategy, the following status codes will be retried:
- 429 (Too Many Requests)
- 408 (Request Timeout)
- 5xx (Server Error)
For the Custom strategy, the status codes specified in the status_codes field will be retried.
For the All strategy, all non-success status codes will be retried.